@@ -1,6 +1,6 @@
 package cache
 
-import "github.com/aquasecurity/fanal/cache"
+import "github.com/aquasecurity/trivy/pkg/fanal/cache"
 
 func NopCache(ac cache.ArtifactCache) cache.Cache {
 	return nopCache{ArtifactCache: ac}
