@@ -4,11 +4,13 @@ import (
 	"os"
 	"path/filepath"
 	"testing"
+	"time"
 
 	"github.com/stretchr/testify/require"
 
 	fixtures "github.com/aquasecurity/bolt-fixtures"
 	"github.com/aquasecurity/trivy-db/pkg/db"
+	jdb "github.com/aquasecurity/trivy-java-db/pkg/db"
 )
 
 // InitDB initializes testing database.
@@ -36,3 +38,20 @@ func InitDB(t *testing.T, fixtureFiles []string) string {
 func Close() error {
 	return db.Close()
 }
+
+func InitJavaDB(t *testing.T, cacheDir string) {
+	dbDir := filepath.Join(cacheDir, "java-db")
+	javaDB, err := jdb.New(dbDir)
+	require.NoError(t, err)
+	err = javaDB.Init()
+	require.NoError(t, err)
+
+	meta := jdb.Metadata{
+		Version:    jdb.SchemaVersion,
+		NextUpdate: time.Now().Add(24 * time.Hour),
+		UpdatedAt:  time.Now(),
+	}
+	metac := jdb.NewMetadata(dbDir)
+	err = metac.Update(meta)
+	require.NoError(t, err)
+}
