@@ -3,6 +3,9 @@ package secret
 import (
 	"fmt"
 
+	"github.com/samber/lo"
+
+	defsecRules "github.com/aquasecurity/defsec/pkg/rules"
 	"github.com/aquasecurity/trivy/pkg/fanal/types"
 )
 
@@ -76,6 +79,16 @@ const (
 	aws = `(aws)?_?`
 )
 
+// This function is exported for trivy-plugin-aqua purposes only
+func GetSecretRulesMetadata() []defsecRules.Check {
+	return lo.Map(builtinRules, func(rule Rule, i int) defsecRules.Check {
+		return defsecRules.Check{
+			Name:        rule.ID,
+			Description: rule.Title,
+		}
+	})
+}
+
 var builtinRules = []Rule{
 	{
 		ID:              "aws-access-key-id",
