@@ -6,6 +6,7 @@ import (
 	"fmt"
 	"os"
 	"path/filepath"
+	"sort"
 	"time"
 
 	"golang.org/x/xerrors"
@@ -18,8 +19,7 @@ import (
 )
 
 const (
-	defaultJavaDBRepository = "ghcr.io/aquasecurity/trivy-java-db"
-	mediaType               = "application/vnd.aquasec.trivy.javadb.layer.v1.tar+gzip"
+	mediaType = "application/vnd.aquasec.trivy.javadb.layer.v1.tar+gzip"
 )
 
 var updater *Updater
@@ -48,6 +48,7 @@ func (u *Updater) Update() error {
 
 	if (meta.Version != db.SchemaVersion || meta.NextUpdate.Before(time.Now().UTC())) && !u.skip {
 		// Download DB
+		log.Logger.Infof("Java DB Repository: %s", u.repo)
 		log.Logger.Info("Downloading the Java DB...")
 
 		var a *oci.Artifact
@@ -76,9 +77,9 @@ func (u *Updater) Update() error {
 	return nil
 }
 
-func Init(cacheDir string, skip, quiet, insecure bool) {
+func Init(cacheDir string, javaDBRepository string, skip, quiet, insecure bool) {
 	updater = &Updater{
-		repo:     fmt.Sprintf("%s:%d", defaultJavaDBRepository, db.SchemaVersion), // TODO: make it configurable
+		repo:     fmt.Sprintf("%s:%d", javaDBRepository, db.SchemaVersion),
 		dbDir:    filepath.Join(cacheDir, "java-db"),
 		skip:     skip,
 		quiet:    quiet,
@@ -142,6 +143,9 @@ func (d *DB) SearchByArtifactID(artifactID string) (string, error) {
 	} else if len(indexes) == 0 {
 		return "", xerrors.Errorf("artifactID %s: %w", artifactID, jar.ArtifactNotFoundErr)
 	}
+	sort.Slice(indexes, func(i, j int) bool {
+		return indexes[i].GroupID < indexes[j].GroupID
+	})
 
 	// Some artifacts might have the same artifactId.
 	// e.g. "javax.servlet:jstl" and "jstl:jstl"
@@ -157,6 +161,7 @@ func (d *DB) SearchByArtifactID(artifactID string) (string, error) {
 	var groupID string
 	for k, v := range groupIDs {
 		if v > maxCount {
+			maxCount = v
 			groupID = k
 		}
 	}
