@@ -4,15 +4,16 @@ import (
 	"bytes"
 	"fmt"
 	"path/filepath"
+	"sort"
 	"strings"
 	"sync"
 
 	"github.com/samber/lo"
 	"github.com/xlab/treeprint"
-
-	"github.com/aquasecurity/tml"
+	"golang.org/x/exp/maps"
 
 	"github.com/aquasecurity/table"
+	"github.com/aquasecurity/tml"
 	dbTypes "github.com/aquasecurity/trivy-db/pkg/types"
 	ftypes "github.com/aquasecurity/trivy/pkg/fanal/types"
 	"github.com/aquasecurity/trivy/pkg/log"
@@ -71,7 +72,14 @@ func (r *vulnerabilityRenderer) setHeaders() {
 	if len(r.result.Vulnerabilities) == 0 {
 		return
 	}
-	header := []string{"Library", "Vulnerability", "Severity", "Installed Version", "Fixed Version", "Title"}
+	header := []string{
+		"Library",
+		"Vulnerability",
+		"Severity",
+		"Installed Version",
+		"Fixed Version",
+		"Title",
+	}
 	r.tableWriter.SetHeaders(header...)
 }
 
@@ -106,12 +114,21 @@ func (r *vulnerabilityRenderer) setVulnerabilityRows(vulns []types.DetectedVulne
 		var row []string
 		if r.isTerminal {
 			row = []string{
-				lib, v.VulnerabilityID, ColorizeSeverity(v.Severity, v.Severity),
-				v.InstalledVersion, v.FixedVersion, strings.TrimSpace(title),
+				lib,
+				v.VulnerabilityID,
+				ColorizeSeverity(v.Severity, v.Severity),
+				v.InstalledVersion,
+				v.FixedVersion,
+				strings.TrimSpace(title),
 			}
 		} else {
 			row = []string{
-				lib, v.VulnerabilityID, v.Severity, v.InstalledVersion, v.FixedVersion, strings.TrimSpace(title),
+				lib,
+				v.VulnerabilityID,
+				v.Severity,
+				v.InstalledVersion,
+				v.FixedVersion,
+				strings.TrimSpace(title),
 			}
 		}
 
@@ -133,6 +150,7 @@ func (r *vulnerabilityRenderer) renderDependencyTree() {
 	if len(parents) == 0 {
 		return
 	}
+	ancestors := traverseAncestors(r.result.Packages, parents)
 
 	root := treeprint.NewWithRoot(fmt.Sprintf(`
 Dependency Origin Tree (Reversed)
@@ -152,19 +170,20 @@ Dependency Origin Tree (Reversed)
 		pkgSeverityCount[vuln.PkgID] = cnts
 	}
 
+	// Extract vulnerable packages
+	vulnPkgs := lo.Filter(r.result.Packages, func(pkg ftypes.Package, _ int) bool {
+		return lo.ContainsBy(r.result.Vulnerabilities, func(vuln types.DetectedVulnerability) bool {
+			return pkg.ID == vuln.PkgID
+		})
+	})
+
 	// Render tree
-	seen := map[string]struct{}{}
-	for _, vuln := range r.result.Vulnerabilities {
-		if _, ok := seen[vuln.PkgID]; ok {
-			continue
-		}
+	for _, vulnPkg := range vulnPkgs {
+		_, summaries := summarize(r.severities, pkgSeverityCount[vulnPkg.ID])
+		topLvlID := tml.Sprintf("<red>%s, (%s)</red>", vulnPkg.ID, strings.Join(summaries, ", "))
 
-		_, summaries := summarize(r.severities, pkgSeverityCount[vuln.PkgID])
-		topLvlID := tml.Sprintf("<red>%s, (%s)</red>", vuln.PkgID, strings.Join(summaries, ", "))
-
-		seen[vuln.PkgID] = struct{}{}
 		branch := root.AddBranch(topLvlID)
-		addParents(branch, vuln.PkgID, parents, map[string]struct{}{})
+		addParents(branch, vulnPkg, parents, ancestors, map[string]struct{}{vulnPkg.ID: {}}, 1)
 
 	}
 	r.printf(root.String())
@@ -175,33 +194,82 @@ func (r *vulnerabilityRenderer) printf(format string, args ...interface{}) {
 	_ = tml.Fprintf(r.w, format, args...)
 }
 
-func addParents(topItem treeprint.Tree, pkgID string, parentMap map[string][]string, seen map[string]struct{}) {
-	seen[pkgID] = struct{}{} // to avoid infinite loops
-
-	for _, parent := range parentMap[pkgID] {
-		if _, ok := seen[parent]; ok {
-			return
-		}
-		branch := topItem.AddBranch(parent)
-		addParents(branch, parent, parentMap, seen)
+func addParents(topItem treeprint.Tree, pkg ftypes.Package, parentMap map[string]ftypes.Packages, ancestors map[string][]string,
+	seen map[string]struct{}, depth int) {
+	if !pkg.Indirect {
+		return
 	}
-}
 
-func reverseDeps(libs []ftypes.Package) map[string][]string {
-	reversed := make(map[string][]string)
-	for _, lib := range libs {
-		for _, dependOn := range lib.DependsOn {
-			items, ok := reversed[dependOn]
-			if !ok {
-				reversed[dependOn] = []string{lib.ID}
-			} else {
-				reversed[dependOn] = append(items, lib.ID)
+	roots := map[string]struct{}{}
+	for _, parent := range parentMap[pkg.ID] {
+		if _, ok := seen[parent.ID]; ok {
+			continue
+		}
+		seen[parent.ID] = struct{}{} // to avoid infinite loops
+
+		if depth == 1 && !parent.Indirect {
+			topItem.AddBranch(parent.ID)
+		} else {
+			// We omit intermediate dependencies and show only direct dependencies
+			// as this could make the dependency tree huge.
+			for _, ancestor := range ancestors[parent.ID] {
+				roots[ancestor] = struct{}{}
 			}
 		}
 	}
 
+	// Omitted
+	rootIDs := lo.Filter(maps.Keys(roots), func(pkgID string, _ int) bool {
+		_, ok := seen[pkgID]
+		return !ok
+	})
+	sort.Strings(rootIDs)
+	if len(rootIDs) > 0 {
+		branch := topItem.AddBranch("...(omitted)...")
+		for _, rootID := range rootIDs {
+			branch.AddBranch(rootID)
+		}
+	}
+}
+
+func reverseDeps(pkgs []ftypes.Package) map[string]ftypes.Packages {
+	reversed := make(map[string]ftypes.Packages)
+	for _, pkg := range pkgs {
+		for _, dependOn := range pkg.DependsOn {
+			reversed[dependOn] = append(reversed[dependOn], pkg)
+		}
+	}
+
 	for k, v := range reversed {
-		reversed[k] = lo.Uniq(v)
+		reversed[k] = lo.UniqBy(v, func(pkg ftypes.Package) string {
+			return pkg.ID
+		})
 	}
 	return reversed
 }
+
+func traverseAncestors(pkgs []ftypes.Package, parentMap map[string]ftypes.Packages) map[string][]string {
+	ancestors := map[string][]string{}
+	for _, pkg := range pkgs {
+		ancestors[pkg.ID] = findAncestor(pkg.ID, parentMap, map[string]struct{}{})
+	}
+	return ancestors
+}
+
+func findAncestor(pkgID string, parentMap map[string]ftypes.Packages, seen map[string]struct{}) []string {
+	ancestors := map[string]struct{}{}
+	seen[pkgID] = struct{}{}
+	for _, parent := range parentMap[pkgID] {
+		if _, ok := seen[parent.ID]; ok {
+			continue
+		}
+		if !parent.Indirect {
+			ancestors[parent.ID] = struct{}{}
+		} else {
+			for _, a := range findAncestor(parent.ID, parentMap, seen) {
+				ancestors[a] = struct{}{}
+			}
+		}
+	}
+	return maps.Keys(ancestors)
+}
