@@ -222,6 +222,90 @@ func TestClient_FillInfo(t *testing.T) {
 				},
 			},
 		},
+		{
+			name:     "happy path. GHSA-xxx. Severity gets from ghsa",
+			fixtures: []string{"testdata/fixtures/vulnerability.yaml"},
+			vulns: []types.DetectedVulnerability{
+				{VulnerabilityID: "GHSA-0000-aaaa-1111"},
+			},
+			expectedVulnerabilities: []types.DetectedVulnerability{
+				{
+					VulnerabilityID: "GHSA-0000-aaaa-1111",
+					SeveritySource:  vulnerability.GHSA,
+					Vulnerability: dbTypes.Vulnerability{
+						Title:       "dos",
+						Description: "dos vulnerability",
+						Severity:    dbTypes.SeverityHigh.String(),
+						References:  []string{"http://example.com"},
+						VendorSeverity: map[dbTypes.SourceID]dbTypes.Severity{
+							"nvd":  dbTypes.SeverityLow,
+							"ghsa": dbTypes.SeverityHigh,
+						},
+					},
+					PrimaryURL: "https://github.com/advisories/GHSA-0000-aaaa-1111",
+				},
+			},
+		},
+		{
+			name:     "happy path. CVE-xxx. Severity gets from nvd",
+			fixtures: []string{"testdata/fixtures/vulnerability.yaml"},
+			vulns: []types.DetectedVulnerability{
+				{VulnerabilityID: "CVE-2022-0001"},
+			},
+			expectedVulnerabilities: []types.DetectedVulnerability{
+				{
+					VulnerabilityID: "CVE-2022-0001",
+					SeveritySource:  vulnerability.NVD,
+					Vulnerability: dbTypes.Vulnerability{
+						Title:       "dos",
+						Description: "dos vulnerability",
+						Severity:    dbTypes.SeverityLow.String(),
+						References:  []string{"http://example.com"},
+						VendorSeverity: map[dbTypes.SourceID]dbTypes.Severity{
+							"nvd":  dbTypes.SeverityLow,
+							"ghsa": dbTypes.SeverityHigh,
+						},
+					},
+					PrimaryURL: "https://avd.aquasec.com/nvd/cve-2022-0001",
+				},
+			},
+		},
+		{
+			name:     "happy path. CVE-xxx from govuln. Severity gets from ghsa",
+			fixtures: []string{"testdata/fixtures/vulnerability.yaml"},
+			vulns: []types.DetectedVulnerability{
+				{
+					VulnerabilityID: "CVE-2022-0001",
+					DataSource: &dbTypes.DataSource{
+						ID:   vulnerability.GoVulnDB,
+						Name: "The Go Vulnerability Database",
+						URL:  "https://github.com/golang/vulndb",
+					},
+				},
+			},
+			expectedVulnerabilities: []types.DetectedVulnerability{
+				{
+					VulnerabilityID: "CVE-2022-0001",
+					SeveritySource:  vulnerability.GHSA,
+					Vulnerability: dbTypes.Vulnerability{
+						Title:       "dos",
+						Description: "dos vulnerability",
+						Severity:    dbTypes.SeverityHigh.String(),
+						References:  []string{"http://example.com"},
+						VendorSeverity: map[dbTypes.SourceID]dbTypes.Severity{
+							"nvd":  dbTypes.SeverityLow,
+							"ghsa": dbTypes.SeverityHigh,
+						},
+					},
+					DataSource: &dbTypes.DataSource{
+						ID:   vulnerability.GoVulnDB,
+						Name: "The Go Vulnerability Database",
+						URL:  "https://github.com/golang/vulndb",
+					},
+					PrimaryURL: "https://avd.aquasec.com/nvd/cve-2022-0001",
+				},
+			},
+		},
 		{
 			name:     "GetVulnerability returns an error",
 			fixtures: []string{"testdata/fixtures/sad.yaml"},
